==> necroplayer2_0.1.1.tar.gz: necroplayer2-0.1.1/translations/necroplayer2_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>CoverDialog</name>
    <message>
        <location filename="../src/CoverDialog.cpp" line="9"/>
        <source>no artist info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/CoverDialog.cpp" line="10"/>
        <source>no album info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/CoverDialog.cpp" line="14"/>
        <source>Album art</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/CoverDialog.cpp" line="37"/>
        <source>Change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/CoverDialog.cpp" line="38"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/CoverDialog.cpp" line="39"/>
        <source>Done</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/Config.cpp" line="23"/>
        <source>Music</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="10"/>
        <source>Save playing position on quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="11"/>
        <source>Save playing position on quit (second line if needed)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="12"/>
        <source>Pause on headphones disconnect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="13"/>
        <source>Pause on headphones disconnect (second line if needed)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="14"/>
        <source>Resume on headphones connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="15"/>
        <source>Resume on headphones connect (second line if needed)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="16"/>
        <source>Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="17"/>
        <source>New Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="18"/>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="19"/>
        <source>No.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="20"/>
        <source>Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="21"/>
        <source>Browse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="22"/>
        <location filename="../src/SettingsDialog.cpp" line="266"/>
        <source>Done</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="23"/>
        <source>Show descriptions in path display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="24"/>
        <source>Show descriptions in path display (second line if needed)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="25"/>
        <source>Hide description of first directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="26"/>
        <source>Hide description of first directory (second line if needed)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="41"/>
        <source>Player</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="53"/>
        <source>Volume slider</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="58"/>
        <source>System volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="61"/>
        <source>Player volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="75"/>
        <source>Playlist view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="79"/>
        <source>Separators</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="82"/>
        <source>Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="95"/>
        <source>Playlist items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="100"/>
        <source>Metadata</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="103"/>
        <source>Filenames</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="117"/>
        <source>Retrieve metadata</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="121"/>
        <source>Playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="124"/>
        <source>Played song</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="173"/>
        <source>Phone button function</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="176"/>
        <source>Play / Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="177"/>
        <source>Stop playback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="178"/>
        <source>Next song</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="179"/>
        <source>Previous song</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="180"/>
        <source>Do nothing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="190"/>
        <source>Media</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="195"/>
        <source>Directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="252"/>
        <source>Show hidden files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="258"/>
        <source>requires restart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="273"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SimpleViewFM</name>
    <message>
        <location filename="../src/SimpleViewFM.cpp" line="20"/>
        <source>FM transmission frequency (MHz)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UI</name>
    <message>
        <location filename="../src/UI.cpp" line="113"/>
        <source>Playing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="114"/>
        <source>Media</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="150"/>
        <source>further developed by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="151"/>
        <source>based on and inspired by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="152"/>
        <source>Playlist files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="382"/>
        <source>Open Playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="385"/>
        <source>Save Playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="388"/>
        <source>Open Url</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="391"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="394"/>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UILibrary</name>
    <message>
        <location filename="../src/UILibrary.cpp" line="10"/>
        <source>Select view</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UIPlaylist</name>
    <message>
        <location filename="../src/UIPlaylist.cpp" line="10"/>
        <source>Clear playlist</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UrlDialog</name>
    <message>
        <location filename="../src/UrlDialog.cpp" line="12"/>
        <source>Done</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/UrlDialog.cpp" line="13"/>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/UrlDialog.cpp" line="18"/>
        <source>Url</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> necroplayer2_0.2.2.tar.gz: necroplayer2-0.2.2/translations/necroplayer2_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>CoverDialog</name>
    <message>
        <location filename="../src/CoverDialog.cpp" line="9"/>
        <source>no artist info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/CoverDialog.cpp" line="10"/>
        <source>no album info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/CoverDialog.cpp" line="14"/>
        <source>Album art</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/CoverDialog.cpp" line="37"/>
        <source>Change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/CoverDialog.cpp" line="38"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/CoverDialog.cpp" line="39"/>
        <source>Done</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/Config.cpp" line="23"/>
        <source>Music</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="10"/>
        <source>Save playing position on quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="11"/>
        <source>Save playing position on quit (second line if needed)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="12"/>
        <source>Pause on headphones disconnect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="13"/>
        <source>Pause on headphones disconnect (second line if needed)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="14"/>
        <source>Resume on headphones connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="15"/>
        <source>Resume on headphones connect (second line if needed)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="16"/>
        <source>Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="17"/>
        <source>New Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="18"/>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="19"/>
        <source>No.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="20"/>
        <source>Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="21"/>
        <source>Browse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="22"/>
        <location filename="../src/SettingsDialog.cpp" line="266"/>
        <source>Done</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="23"/>
        <source>Show descriptions in path display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="24"/>
        <source>Show descriptions in path display (second line if needed)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="25"/>
        <source>Hide description of first directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="26"/>
        <source>Hide description of first directory (second line if needed)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="41"/>
        <source>Player</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="53"/>
        <source>Volume slider</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="58"/>
        <source>System volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="61"/>
        <source>Player volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="75"/>
        <source>Playlist view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="79"/>
        <source>Separators</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="82"/>
        <source>Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="95"/>
        <source>Playlist items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="100"/>
        <source>Metadata</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="103"/>
        <source>Filenames</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="117"/>
        <source>Retrieve metadata</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="121"/>
        <source>Playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="124"/>
        <source>Played song</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="173"/>
        <source>Phone button function</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="176"/>
        <source>Play / Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="177"/>
        <source>Stop playback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="178"/>
        <source>Next song</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="179"/>
        <source>Previous song</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="180"/>
        <source>Do nothing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="190"/>
        <source>Media</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="195"/>
        <source>Directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="252"/>
        <source>Show hidden files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="258"/>
        <source>requires restart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="273"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SimpleViewFM</name>
    <message>
        <location filename="../src/SimpleViewFM.cpp" line="22"/>
        <source>FM transmission frequency (MHz)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UI</name>
    <message>
        <location filename="../src/UI.cpp" line="113"/>
        <source>Playing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="114"/>
        <source>Media</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="150"/>
        <source>further developed by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="151"/>
        <source>based on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="152"/>
        <source>Playlist files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="382"/>
        <source>Open Playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="385"/>
        <source>Save Playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="388"/>
        <source>Open Url</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="391"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="394"/>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UILibrary</name>
    <message>
        <location filename="../src/UILibrary.cpp" line="11"/>
        <source>Select view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/UILibrary.cpp" line="12"/>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/UILibrary.cpp" line="13"/>
        <source>Confirm deletion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/UILibrary.cpp" line="33"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UIPlaylist</name>
    <message>
        <location filename="../src/UIPlaylist.cpp" line="10"/>
        <source>Clear playlist</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UrlDialog</name>
    <message>
        <location filename="../src/UrlDialog.cpp" line="12"/>
        <source>Done</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/UrlDialog.cpp" line="13"/>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/UrlDialog.cpp" line="18"/>
        <source>Url</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
